﻿using System.Windows;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Windows.Data;
using System.Globalization;
using System;

namespace ConvertBack_ConcatenatedFields
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		public MainWindow()
		{
			InitializeComponent();
			InitializeComponent();

			this.dateGrid.ItemsSource = this.CreateDataViews();
		}

		private Collection<DateType> CreateDataSource()
		{
			Collection<DateType> dateTypes = new Collection<DateType>();

			dateTypes.Add(new DateType(26, 02, 1876));
			dateTypes.Add(new DateType(31, 05, 1878));
			dateTypes.Add(new DateType(05, 11, 1986));
			dateTypes.Add(new DateType(21, 09, 1988));
			dateTypes.Add(new DateType(10, 10, 1970));

			return dateTypes;
		}

		private Collection<DateTypeView> CreateDataViews()
		{

			var dateTypes = this.CreateDataSource();
			Collection<DateTypeView> views = new Collection<DateTypeView>();

			foreach (var date in dateTypes)
			{
				views.Add(new DateTypeView(date));
			}

			return views;
		}
	}

	public class IDConverter : IValueConverter
	{
		public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
		{
			DateType dateType = value as DateType;
			if (dateType != null)
			{
				return dateType.Day.ToString() + "." + dateType.Month.ToString() + "." + dateType.Year.ToString();
			}
			return value;
		}

		public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
		{
			return value;
		}
	}


	public class DateType : INotifyPropertyChanged
	{
		public event PropertyChangedEventHandler PropertyChanged;

		private int day;

		private int month;
		private int year;

		public int Day
		{
			get { return this.day; }
			set
			{
				if (value != this.day)
				{
					this.day = value;
					this.OnPropertyChanged("Day");
				}
			}
		}

		public int Month
		{
			get { return this.month; }
			set
			{
				if (value != this.month)
				{
					this.month = value;
					this.OnPropertyChanged("Month");
				}
			}
		}
		public int Year
		{
			get { return this.year; }
			set
			{
				if (value != this.year)
				{
					this.year = value;
					this.OnPropertyChanged("Year");
				}
			}
		}

		protected virtual void OnPropertyChanged(PropertyChangedEventArgs args)
		{
			PropertyChangedEventHandler handler = this.PropertyChanged;
			if (handler != null)
			{
				handler(this, args);
			}
		}

		private void OnPropertyChanged(string propertyName)
		{
			this.OnPropertyChanged(new PropertyChangedEventArgs(propertyName));
		}

		public override string ToString()
		{
			return base.ToString();
		}

		public DateType(int day, int month, int year)
		{
			this.day = day;
			this.month = month;
			this.year = year;
		}
	}
}